@@ -13,16 +13,16 @@
 # under the License.
 
 from django.utils.translation import ugettext_lazy as _  # noqa
-from django.views.decorators.debug import sensitive_variables  # noqa
+from django.views.decorators.debug import sensitive_variables
 
 from horizon import exceptions
 from horizon import forms
-from horizon import workflows
 from horizon.utils import memoized
+from horizon import workflows
 
-from monitoring import api
 from monitoring.alarmdefs import constants
 from monitoring.alarmdefs import forms as ad_forms
+from monitoring import api
 
 
 class SetAlarmNotificationsAction(workflows.Action):
@@ -100,13 +100,15 @@ class SetAlarmDefinitionAction(workflows.Action):
     def clean(self):
         cleaned_data = super(SetAlarmDefinitionAction, self).clean()
 
-        alarm_def_name = cleaned_data.get('name', '')
+        alarm_def_name = cleaned_data.get('name', '').strip()
+        if not alarm_def_name:
+            return
         is_name_valid = self._is_alarm_def_name_unique_validator(
             alarm_def_name)
         if not is_name_valid:
             self.add_error('name',
                            _('Alarm definition with %s name already exists')
-                             % alarm_def_name)
+                           % alarm_def_name)
 
     def _is_alarm_def_name_unique_validator(self, value):
         try:
