@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,18 +11,16 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from django.conf.urls import patterns  # noqa
 from django.conf.urls import url  # noqa
 
 from monitoring.notifications import views
 
-urlpatterns = patterns(
-    '',
+urlpatterns = [
     url(r'^$', views.IndexView.as_view(), name='index'),
     url(r'^notification_create$',
         views.NotificationCreateView.as_view(),
         name='notification_create'),
     url(r'^notification_edit/(?P<id>[^/]+)$',
         views.NotificationEditView.as_view(),
-        name='notification_edit'),
-)
+        name='notification_edit')
+]
