@@ -17,6 +17,7 @@ import copy
 import json
 import logging
 
+from django.conf import settings
 from django.contrib import messages
 from django import http
 from django.http import HttpResponse
@@ -25,16 +26,14 @@ from django.utils.translation import ugettext_lazy as _  # noqa
 from django.views.decorators.csrf import csrf_exempt
 from django.views import generic
 from django.views.generic import TemplateView
+from horizon import exceptions
 from openstack_auth import utils as auth_utils
 from openstack_dashboard import policy
 import six
 from six.moves import urllib
 
-from horizon import exceptions
-
 from monitoring.alarms import tables as alarm_tables
 from monitoring import api
-from monitoring.config import local_settings as settings
 from monitoring.overview import constants
 
 LOG = logging.getLogger(__name__)
@@ -282,8 +281,12 @@ class MonascaProxyView(TemplateView):
                 # the `url` dimension of the service_status check.
                 dimension_name_value = dimension.split(':', 1)
                 if len(dimension_name_value) == 2:
-                    name = dimension_name_value[0].encode('utf8')
-                    value = dimension_name_value[1].encode('utf8')
+                    if six.PY2:
+                        name = dimension_name_value[0].encode('utf8')
+                        value = dimension_name_value[1].encode('utf8')
+                    else:
+                        name = dimension_name_value[0]
+                        value = dimension_name_value[1]
                     dim_dict[name] = urllib.parse.unquote(value)
                 else:
                     raise Exception('Dimensions are malformed')
@@ -415,9 +418,10 @@ class KibanaProxyView(generic.View):
 
         # passing kbn version explicitly for kibana >= 4.3.x
         headers = {
-            'X-Auth-Token': request.user.token.id,
-            'kbn-version': request.META.get('HTTP_KBN_VERSION', ''),
-            'Cookie': request.META.get('HTTP_COOKIE', '')
+            "X-Auth-Token": request.user.token.id,
+            "kbn-version": request.META.get("HTTP_KBN_VERSION", ""),
+            "Cookie": request.META.get("HTTP_COOKIE", ""),
+            "Content-Type": "application/json",
         }
 
         return self.read(request.method, url, request.body, headers)
